@@ -36,32 +36,35 @@ def pyhackrf_info(print_to_console: bool = True, initialize: bool = True) -> str
         for i in range(device_list.device_count):
             print_info += 'Found HackRF:\n'
             device = pyhackrf.pyhackrf_open_by_serial(device_list.serial_numbers[i])
-            board_id, board_id_name = device.pyhackrf_board_id_read()
-            board_rev, board_rev_name = device.pyhackrf_board_rev_read()
-            read_partid_serialno = device.pyhackrf_board_partid_serialno_read()
-            print_info += f'Index: {i}\n'
-            print_info += f'Serial number: {device_list.serial_numbers[i]}\n'
-            print_info += f'Board ID Number: {board_id} ({board_id_name})\n'
-            print_info += f'Firmware Version: {device.pyhackrf_version_string_read()} ({device.pyhackrf_usb_api_version_read()})\n'
-            print_info += f'Part ID Number: 0x{read_partid_serialno[0][0]:08x} 0x{read_partid_serialno[0][1]:08x}\n'
-            if board_rev not in {0xFE, 0xFF}:
-                print_info += f'Hardware Revision: {board_rev_name}\n'
-                if board_rev > 0:
-                    if (board_rev & 0x80):
-                        print_info += 'Hardware appears to have been manufactured by Great Scott Gadgets.\n'
-                    else:
-                        print_info += 'Hardware does not appear to have been manufactured by Great Scott Gadgets.\n'
-            else:
-                print_info += f'{board_rev_name}\n'
-            operacake_boards = device.pyhackrf_get_operacake_boards()
-            for operacake_board_address in operacake_boards:
-                mode = device.pyhackrf_get_operacake_mode(operacake_board_address)
-                print_info += f'Opera Cake found, address: {operacake_board_address} | switching mode: {mode}'
+            if device:
+                board_id, board_id_name = device.pyhackrf_board_id_read()
+                board_rev, board_rev_name = device.pyhackrf_board_rev_read()
+                read_partid_serialno = device.pyhackrf_board_partid_serialno_read()
+                print_info += f'Index: {i}\n'
+                print_info += f'Serial number: {device_list.serial_numbers[i]}\n'
+                print_info += f'Board ID Number: {board_id} ({board_id_name})\n'
+                print_info += f'Firmware Version: {device.pyhackrf_version_string_read()} ({device.pyhackrf_usb_api_version_read()})\n'
+                print_info += f'Part ID Number: 0x{read_partid_serialno[0][0]:08x} 0x{read_partid_serialno[0][1]:08x}\n'
+                if board_rev not in {0xFE, 0xFF}:
+                    print_info += f'Hardware Revision: {board_rev_name}\n'
+                    if board_rev > 0:
+                        if (board_rev & 0x80):
+                            print_info += 'Hardware appears to have been manufactured by Great Scott Gadgets.\n'
+                        else:
+                            print_info += 'Hardware does not appear to have been manufactured by Great Scott Gadgets.\n'
+                else:
+                    print_info += f'{board_rev_name}\n'
 
-            device.pyhackrf_close()
+                operacake_boards = device.pyhackrf_get_operacake_boards()
+                for operacake_board_address in operacake_boards:
+                    mode = device.pyhackrf_get_operacake_mode(operacake_board_address)
+                    print_info += f'Opera Cake found, address: {operacake_board_address} | switching mode: {mode}'
+
+                device.pyhackrf_close()
     else:
         print_info += 'No HackRF boards found.'
 
+    del device_list
     if initialize:
         pyhackrf.pyhackrf_exit()
 
@@ -72,17 +75,20 @@ def pyhackrf_info(print_to_console: bool = True, initialize: bool = True) -> str
     return print_info
 
 
-def pyhackrf_serial_numbers_list_info(print_to_console: bool = True, initialize: bool = True) -> tuple[int, list] | None:
+def pyhackrf_serial_numbers_list_info(print_to_console: bool = True, initialize: bool = True) -> tuple[int, list[str]] | None:
     if initialize:
         pyhackrf.pyhackrf_init()
 
     device_list = pyhackrf.pyhackrf_device_list()
+    device_count = device_list.device_count
+    serial_numbers = device_list.serial_numbers
 
+    del device_list
     if initialize:
         pyhackrf.pyhackrf_exit()
 
     if print_to_console:
-        print(f'Serial numbers [{device_list.device_count}]: {device_list.serial_numbers}')
+        print(f'Serial numbers [{device_count}]: {serial_numbers}')
         return None
 
-    return device_list.device_count, device_list.serial_numbers
+    return device_count, serial_numbers
